<?php
/************************************************************************
 * MXChange v0.2.1                                    Start: 02/28/2009 *
 * ===============                              Last change: 02/28/2009 *
 *                                                                      *
 * -------------------------------------------------------------------- *
 * File              : config-functions.php                             *
 * -------------------------------------------------------------------- *
 * Short description : Many non-MySQL functions (also file access)      *
 * -------------------------------------------------------------------- *
 * Kurzbeschreibung  : Viele Nicht-MySQL-Funktionen (auch Dateizugriff) *
 * -------------------------------------------------------------------- *
 * $Revision::                                                        $ *
 * $Date::                                                            $ *
 * $Tag:: 0.2.1-FINAL                                                 $ *
 * $Author::                                                          $ *
 * Needs to be in all Files and every File needs "svn propset           *
 * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
 * -------------------------------------------------------------------- *
 * Copyright (c) 2003 - 2008 by Roland Haeder                           *
 * For more information visit: http://www.mxchange.org                  *
 *                                                                      *
 * This program is free software; you can redistribute it and/or modify *
 * it under the terms of the GNU General Public License as published by *
 * the Free Software Foundation; either version 2 of the License, or    *
 * (at your option) any later version.                                  *
 *                                                                      *
 * This program is distributed in the hope that it will be useful,      *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of       *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the        *
 * GNU General Public License for more details.                         *
 *                                                                      *
 * You should have received a copy of the GNU General Public License    *
 * along with this program; if not, write to the Free Software          *
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,               *
 * MA  02110-1301  USA                                                  *
 ************************************************************************/

// Some security stuff...
if (!defined('__SECURITY')) {
	$INC = substr(dirname(__FILE__), 0, strpos(dirname(__FILE__), '/inc') + 4) . '/security.php';
	require($INC);
}

// Merges $_CONFIG with data in given array
function mergeConfig ($newConfig) {
	global $_CONFIG;
	$_CONFIG = merge_array($_CONFIG, $newConfig);
}

// Getter for $_CONFIG entries
function getConfig ($entry) {
	global $_CONFIG;

	// Default value
	$value = null;

	// Is the entry there?
	if (isConfigEntrySet($entry)) {
		// Then use it
		$value = $_CONFIG[$entry];
	} // END - if

	// Return it
	return $value;
}

// Setter for $_CONFIG entries
function setConfigEntry ($entry, $value) {
	global $_CONFIG;

	// Secure the entry name
	$entry = SQL_ESCAPE($entry);

	// And set it
	$_CONFIG[$entry] = $value;
}

// Checks wether the given config entry is set
function isConfigEntrySet ($entry) {
	global $_CONFIG;
	return (isset($_CONFIG[$entry]));
}

// Increment or init with given value or 1 as default the given config entry
function incrementConfigEntry ($configEntry, $value=1) {
	global $_CONFIG;

	// Increment it if set or init it with 1
	if (getConfig($configEntry) > 0) {
		$_CONFIG[$configEntry] += $value;
	} else {
		$_CONFIG[$configEntry] = $value;
	}
}

// Checks wether the configuration array is set so the config is loaded
function isConfigLoaded () {
	global $_CONFIG;

	// Check all
	return ((isset($_CONFIG)) && (is_array($_CONFIG)) && (count($_CONFIG) > 0));
}

// Init the config array
function initConfig () {
	global $_CONFIG;

	// Set a minimum dummy configuration
	$_CONFIG = array(
		'code_length' => 0,
		'patch_level' => 0,
		'last_update' => time()
	);
}

// Load configuration and return it as an arry
function loadConfiguration ($no="0") {
	global $_CONFIG;

	// Check for cache extension, cache-array and if the requested configuration is in cache
	if ((is_array($GLOBALS['cache_array'])) && (isset($GLOBALS['cache_array']['config'][$no])) && (is_array($GLOBALS['cache_array']['config'][$no]))) {
		// Load config from cache
		//* DEBUG: */ echo gettype($GLOBALS['cache_array']['config'][$no])."<br />\n";
		foreach ($GLOBALS['cache_array']['config'][$no] as $key => $value) {
			$_CONFIG[$key] = $value;
		} // END - foreach

		// Count cache hits if exists
		if ((isset($_CONFIG['cache_hits'])) && (EXT_IS_ACTIVE('cache'))) {
			$_CONFIG['cache_hits']++;
		} // END - if
	} elseif ((!EXT_IS_ACTIVE('cache')) || (!isset($GLOBALS['cache_array']['config'][$no]))) {
		// Load config from DB
		$result_config = SQL_QUERY_ESC("SELECT * FROM `{!_MYSQL_PREFIX!}_config` WHERE config=%d LIMIT 1",
			array(bigintval($no)), __FUNCTION__, __LINE__);

		// Is the config there?
		if (SQL_NUMROWS($result_config) == 1) {
			// Get config from database
			$_CONFIG = SQL_FETCHARRAY($result_config);
		} // END - if

		// Free result
		SQL_FREERESULT($result_config);

		// Remember this config in the array
		$GLOBALS['cache_array']['config'][$no] = $_CONFIG;
	}
}

// Getter for whole $_CONFIG array
function getConfigArray () {
	global $_CONFIG;

	// Return it
	return $_CONFIG;
}

// [EOF]
?>
